# Resources

* Compilation of free knowledge and educational resources : <https://econiverse.github.io>
* Hedge fund letters or reports : <https://miltonfmr.com/hedge-fund-letters/>
* Open MIT Open Online course on equity options: <https://ocw.mit.edu/courses/sloan-school-of-management/15-401-finance-theory-i-fall-2008/video-lectures-and-slides/options/>
